diff graal/GraalCompiler/src/com/sun/c1x/ir/TableSwitch.java @ 2741:a3cd5eb68837

more GraphBuilder cleanup, moved mergeOrClone to GraphBuilder
author Lukas Stadler <lukas.stadler@jku.at>
date Fri, 20 May 2011 11:11:33 +0200
parents a0dd2b907806
children 6048da340364
line wrap: on
line diff
--- a/graal/GraalCompiler/src/com/sun/c1x/ir/TableSwitch.java	Fri May 20 10:16:39 2011 +0200
+++ b/graal/GraalCompiler/src/com/sun/c1x/ir/TableSwitch.java	Fri May 20 11:11:33 2011 +0200
@@ -45,12 +45,12 @@
      * @param value the instruction producing the value being switched on
      * @param successors the list of successors
      * @param lowKey the lowest integer key in the table
      * @param stateBefore the state before the switch
      * @param isSafepoint {@code true} if this instruction is a safepoint
      * @param graph
      */
-    public TableSwitch(Value value, List<BlockBegin> successors, int lowKey, FrameState stateBefore, Graph graph) {
-        super(value, successors, stateBefore, INPUT_COUNT, SUCCESSOR_COUNT, graph);
+    public TableSwitch(Value value, List<BlockBegin> successors, int lowKey, FrameState stateAfter, Graph graph) {
+        super(value, successors, stateAfter, INPUT_COUNT, SUCCESSOR_COUNT, graph);
         this.lowKey = lowKey;
     }
@@ -45,12 +45,12 @@
      * @param successors the list of successors
      * @param lowKey the lowest integer key in the table
-     * @param stateBefore the state before the switch
+     * @param stateAfter the state after the switch
      * @param isSafepoint {@code true} if this instruction is a safepoint
      * @param graph